@@ -2,13 +2,14 @@
 #' 
 #' @name income_tax
 #' @param income The individual assessable income.
-#' @param fy.year The financial year in which the income was earned. Only tax years from 2000-01 to 2016-17 are available. 
+#' @param fy.year The financial year in which the income was earned. Tax years 2000-01 to 2016-17 are provided, as well as the tax years 2017-18 to 2019-20, for convenience, under the assumption the 2017 Budget measures will pass. 
+#' In particular, the tax payable is calculated under the assumption that the rate of the Medicare levy will rise to 2.5\% in the 2019-20 tax year.
 #' @param age The individual's age.
-#' @param family_status For medicare and SAPTO purposes.
+#' @param family_status For Medicare and SAPTO purposes.
 #' @param n_dependants An integer for the number of children of the taxpayer (for the purposes of the Medicare levy).
 #' @param return.mode The mode (numeric or integer) of the returned vector.
 #' @param .dots.ATO A data.frame that contains additional information about the individual's circumstances, with columns the same as in the ATO sample files. If \code{.dots.ATO} is a \code{data.table}, I recommend you enclose it with \code{copy()}.
-#' @param allow.forecasts should dates beyond 2016-17 be permitted? Currently, not permitted.
+#' @param allow.forecasts should dates beyond 2019-20 be permitted? Currently, not permitted.
 #' @author Tim Cameron, Brendan Coates, Hugh Parsonage, William Young
 #' @details The function 'rolling' is inflexible by design. It is designed to guarantee the correct tax payable in a year.
 #' For years preceding the introduction of SAPTO, the maximum offset is assumed to apply to those above pensionable age. 
@@ -113,7 +114,7 @@ rolling_income_tax <- function(income,
   #   setkey(fy_year, income)
   
   tax_fun <- function(income, fy.year){
-    setkey(input, fy_year, income)
+    setkeyv(input, c("fy_year", "income"))
     
     tax_table2[input, roll = Inf] %>%
       .[, tax := tax_at + (income - lower_bracket) * marginal_rate] %>%
